@@ -1,6 +1,6 @@
 package App::Sqitch::DateTime;
 
-use v5.10.1;
+use 5.010;
 use strict;
 use warnings;
 use utf8;
@@ -8,7 +8,7 @@ use parent 'DateTime';
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 
-our $VERSION = '0.935';
+our $VERSION = '0.936';
 
 sub as_string_formats {
     return qw(
