@@ -1,6 +1,6 @@
 package App::Sqitch::Engine::sqlite;
 
-use v5.10.1;
+use 5.010;
 use strict;
 use warnings;
 use utf8;
@@ -9,7 +9,7 @@ use Moose;
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = '0.935';
+our $VERSION = '0.936';
 
 has client => (
     is       => 'ro',
