@@ -1,6 +1,6 @@
 package MockOutput;
 
-use v5.10.1;
+use 5.010;
 use strict;
 use warnings;
 use utf8;
